@@ -18,7 +18,7 @@ sub extension {
     my @parts = split /\./, $self->name;
     
     if (scalar @parts > 1) {
-        return $parts[-1];
+        return lc $parts[-1];
     }
 
     return '';
@@ -36,7 +36,7 @@ sub path {
 sub full_path {
     my $self = shift;
     my $dir = $self->dir;
-    return $dir->full_path . $self->name;
+    return $self->name;
 }
 
 sub new {
